/*----------------------------------------------------------------------------
 * map-table.h	- data structures of map tables (version 2)
 *
 * Location: /usr/local/include/map-table.h
 *
 *----------------------------------------------------------------------------
 */

#define MAX_USED_CHARSETS   8			/* max. 8 escape sequences  */
#define MAX_ESC_LEN	    32			/* max. len of sequence	    */

#define MAX_KEYS	    512			/* 512 possible keys	    */
#define MAX_KEY_SEQ_LEN	    8			/* max sequence length	    */

char charset[MAX_USED_CHARSETS][MAX_ESC_LEN];	/* the escape sequences	    */

struct
{
    char	    chset_no;			/* number of character set  */
    unsigned char   ch_out;			/* character to be sent	    */
} map_table[256];

unsigned char key_table[MAX_KEYS][MAX_KEY_SEQ_LEN];
						/* 512 keys, seq-length 8   */

char * keyname_table[] =
{
    "NUL",					/* 0x00			    */
    "CTRL_A",					/* 0x01			    */
    "CTRL_B",					/* 0x02			    */
    "CTRL_C",					/* 0x03			    */
    "CTRL_D",					/* 0x04			    */
    "CTRL_E",					/* 0x05			    */
    "CTRL_F",					/* 0x06			    */
    "CTRL_G",					/* 0x07			    */
    "CTRL_H",					/* 0x08			    */
    "CTRL_I",					/* 0x09			    */
    "CTRL_J",					/* 0x0A			    */
    "CTRL_K",					/* 0x0B			    */
    "CTRL_L",					/* 0x0C			    */
    "CTRL_M",					/* 0x0D			    */
    "CTRL_N",					/* 0x0E			    */
    "CTRL_O",					/* 0x0F			    */
    "CTRL_P",					/* 0x10			    */
    "CTRL_Q",					/* 0x11			    */
    "CTRL_R",					/* 0x12			    */
    "CTRL_S",					/* 0x13			    */
    "CTRL_T",					/* 0x14			    */
    "CTRL_U",					/* 0x15			    */
    "CTRL_V",					/* 0x16			    */
    "CTRL_W",					/* 0x17			    */
    "CTRL_X",					/* 0x18			    */
    "CTRL_Y",					/* 0x19			    */
    "CTRL_Z",					/* 0x1A			    */
    "ESCAPE",					/* 0x1B			    */
    "CTRL_BACKSLASH",				/* 0x1C files sep	    */
    "CTRL_CL_BRACKET",				/* 0x1D	group sep	    */
    "CTRL_CIRCUMFLEX",				/* 0x1E record sep	    */
    "CTRL_UNDERSCORE",				/* 0x1F unit separator	    */
    "SPACE",					/* 0x20			    */
    "EXCLAMATION_MARK",				/* !			    */
    "QUOTATION_MARKS",				/* "			    */
    "NUMBER_SIGN",				/* #			    */
    "DOLLAR_SIGN",				/* $			    */
    "PERCENT_SIGN",				/* %			    */
    "AMPERSAND",				/* &			    */
    "APOSTROPHE",				/* '			    */
    "OP_PARENTHESIS",				/* (			    */
    "CL_PARENTHESIS",				/* )			    */
    "ASTERISK",					/* *			    */
    "PLUS",					/* +			    */
    "COMMA",					/* ,			    */
    "MINUS",					/* -			    */
    "PERIOD",					/* .			    */
    "SLASH",					/* /			    */
    "ZERO",					/* 0			    */
    "ONE",					/* 1			    */
    "TWO",					/* 2			    */
    "THREE",					/* 3			    */
    "FOUR",					/* 4			    */
    "FIVE",					/* 5			    */
    "SIX",					/* 6			    */
    "SEVEN",					/* 7			    */
    "EIGHT",					/* 8			    */
    "NINE",					/* 9			    */
    "COLON",					/* :			    */
    "SEMICOLON",				/* ;			    */
    "LESS_THAN",				/* <			    */
    "EQUAL",					/* =			    */
    "GREATER_THAN",				/* >			    */
    "QUESTION_MARK",				/* ?			    */
    "COMMERCIAL_AT",				/* @			    */
    "UP_A",					/* A			    */
    "UP_B",					/* B			    */
    "UP_C",					/* C			    */
    "UP_D",					/* D			    */
    "UP_E",					/* E			    */
    "UP_F",					/* F			    */
    "UP_G",					/* G			    */
    "UP_H",					/* H			    */
    "UP_I",					/* I			    */
    "UP_J",					/* J			    */
    "UP_K",					/* K			    */
    "UP_L",					/* L			    */
    "UP_M",					/* M			    */
    "UP_N",					/* N			    */
    "UP_O",					/* O			    */
    "UP_P",					/* P			    */
    "UP_Q",					/* Q			    */
    "UP_R",					/* R			    */
    "UP_S",					/* S			    */
    "UP_T",					/* T			    */
    "UP_U",					/* U			    */
    "UP_V",					/* V			    */
    "UP_W",					/* W			    */
    "UP_X",					/* X			    */
    "UP_Y",					/* Y			    */
    "UP_Z",					/* Z			    */
    "OP_BRACKET",				/* [			    */
    "BACKSLASH",				/* \			    */
    "CL_BRACKET",				/* ]			    */
    "CIRCUMFLEX",				/* ^			    */
    "UNDERSCORE",				/* _			    */
    "GRAVE_ACCENT",				/* `			    */
    "LO_A",					/* a			    */
    "LO_B",					/* b			    */
    "LO_C",					/* c			    */
    "LO_D",					/* d			    */
    "LO_E",					/* e			    */
    "LO_F",					/* f			    */
    "LO_G",					/* g			    */
    "LO_H",					/* h			    */
    "LO_I",					/* i			    */
    "LO_J",					/* j			    */
    "LO_K",					/* k			    */
    "LO_L",					/* l			    */
    "LO_M",					/* m			    */
    "LO_N",					/* n			    */
    "LO_O",					/* o			    */
    "LO_P",					/* p			    */
    "LO_Q",					/* q			    */
    "LO_R",					/* r			    */
    "LO_S",					/* s			    */
    "LO_T",					/* t			    */
    "LO_U",					/* u			    */
    "LO_V",					/* v			    */
    "LO_W",					/* w			    */
    "LO_X",					/* x			    */
    "LO_Y",					/* y			    */
    "LO_Z",					/* z			    */
    "OP_BRACE",					/* {			    */
    "V_LINE",					/* |			    */
    "CL_BRACE",					/* }			    */
    "TILDE",					/* ~			    */
    "DELETE",					/* 0x7f			    */

/*----------------------------------------------------------------------------
 * 128 characters of ISO 8859/1 (upper half, extended by graphic characters):
 *--------------------------------------------------------------------------*/

    "",						/* 0x80			    */
    "",						/* 0x81			    */
    "",						/* 0x82			    */
    "",						/* 0x83			    */
    "",						/* 0x84			    */
    "",						/* 0x85			    */
    "",						/* 0x86			    */
    "",						/* 0x87			    */
    "",						/* 0x88			    */
    "",						/* 0x89			    */
    "LO_RIGHT_CORNER",				/* 0x8A			    */
    "UP_RIGHT_CORNER",				/* 0x8B			    */
    "UP_LEFT_CORNER",				/* 0x8C			    */
    "LO_LEFT_CORNER",				/* 0x8D			    */
    "CROSS_LINES",				/* 0x8E			    */
    "",						/* 0x8F			    */
    "",						/* 0x90			    */
    "HOR_BAR",					/* 0x91			    */
    "",						/* 0x92			    */
    "",						/* 0x93			    */
    "LEFT_T",					/* 0x94			    */
    "RIGHT_T",					/* 0x95			    */
    "BOTTOM_T",					/* 0x96			    */
    "TOP_T",					/* 0x97			    */
    "VERT_BAR",					/* 0x98			    */
    "",						/* 0x99			    */
    "",						/* 0x9A			    */
    "",						/* 0x9B			    */
    "",						/* 0x9C			    */
    "",						/* 0x9D			    */
    "",						/* 0x9E			    */
    "",						/* 0x9F			    */
    "ISO_SPACE",				/* 0xA0			    */
    "INV_EXCLAMATION_MARK",			/* 0xA1	(!)		    */
    "US_CENT",					/* 0xA2 (C|		    */
    "BRITISH_POUND",				/* 0xA3			    */
    "CURRENCY_SYMBOL",				/* 0xA4			    */
    "JAPENESE_YEN",				/* 0xA5			    */
    "BROKEN_VERT_BAR",				/* 0xA6			    */
    "SECTION_SIGN",				/* 0xA7 (german paragraph)  */
    "UMLAUT_ACCENT",				/* 0xA8 (")		    */
    "COPYRIGHT_SYMBOL",				/* 0xA9 ((C))		    */
    "FEMININE_ORDINAL_IC",			/* 0xAA	(a_)		    */
    "OP_GUILLEMENTS",				/* 0xAB	(<<)		    */
    "NOT_SIGN",					/* 0xAC (-|)		    */
    "SHY_SYMBOL",				/* 0xAD SHY		    */
    "REG_TRADE_MARK",				/* 0xAE reg. trademark sym. */
    "OVER_LINE",				/* 0xAF			    */
    "DEGREE",					/* 0xB0 (ring)		    */
    "PLUS_MINUS",				/* 0xB1	(+-)		    */
    "SUPER_2",					/* 0xB2 Superscript 2	    */
    "SUPER_3",					/* 0xB3 Superscript 3	    */
    "ACUTE_ACCENT",				/* 0xB4	(')		    */
    "LO_MU",					/* 0xB5	(micro sign)	    */
    "PILCROW",					/* 0xB6	(paragraph sign)    */
    "MIDDLE_DOT",				/* 0xB7 (.)		    */
    "CEDILLA",					/* 0xB8 yet another comma   */
    "SUPER_1",					/* 0xB9 Superscript 1	    */
    "MASCULINE_ORDINAL_IC",			/* 0xBA	(o_)		    */
    "CL_GUILLEMENTS",				/* 0xBB	(>>)		    */
    "ONE_FOURTH",				/* 0xBC (1/4)		    */
    "ONE_HALF",					/* 0xBD	(1/2)		    */
    "VULGAR_FRACTION_3_4",			/* 0xBE	(3/4)		    */
    "INV_QUESTION_MARK",			/* 0xBF	(?)		    */
    "UP_A_GRAVE_ACCENT",			/* 0xC0	(A`)		    */
    "UP_A_ACUTE_ACCENT",			/* 0xC1	(A')		    */
    "UP_A_CIRCUMFLEX",				/* 0xC2	(A^)		    */
    "UP_A_TILDE_ACCENT",			/* 0xC3	(A~)		    */
    "UP_A_UMLAUT",				/* 0xC4	(A")		    */
    "UP_A_DEGREE",				/* 0xC5	(A ring)	    */
    "UP_AE_LIGATURE",				/* 0xC6	(AE)		    */
    "UP_C_CEDILLA",				/* 0xC7 (Cd)		    */
    "UP_E_GRAVE_ACCENT",			/* 0xC8	(E`)		    */
    "UP_E_ACUTE_ACCENT",			/* 0xC9	(E')		    */
    "UP_E_CIRCUMFLEX",				/* 0xCA	(E^)		    */
    "UP_E_UMLAUT",				/* 0xCB	(E")		    */
    "UP_I_GRAVE_ACCENT",			/* 0xCC	(I`)		    */
    "UP_I_ACUTE_ACCENT",			/* 0xCD	(I')		    */
    "UP_I_CIRCUMFLEX",				/* 0xCE	(I^)		    */
    "UP_I_UMLAUT",				/* 0xCF	(I")		    */
    "UP_D_WITH_STROKE",				/* 0xD0	(D-)		    */
    "UP_N_TILDE_ACCENT",			/* 0xD1	(N~)		    */
    "UP_O_GRAVE_ACCENT",			/* 0xD2	(O`)		    */
    "UP_O_ACUTE_ACCENT",			/* 0xD3	(O')		    */
    "UP_O_CIRCUMFLEX",				/* 0xD4	(O^)		    */
    "UP_O_TILDE_ACCENT",			/* 0xD5	(O~)		    */
    "UP_O_UMLAUT",				/* 0xD6	(O")		    */
    "MATH_TIMES",				/* 0xD7 (x)		    */
    "UP_O_CROSSBAR",				/* 0xD8	(O/)		    */
    "UP_U_GRAVE_ACCENT",			/* 0xD9	(U`)		    */
    "UP_U_ACUTE_ACCENT",			/* 0xDA	(U')		    */
    "UP_U_CIRCUMFLEX",				/* 0xDB	(U^)		    */
    "UP_U_UMLAUT",				/* 0xDC	(U")		    */
    "UP_Y_ACUTE_ACCENT",			/* 0xDD	(Y')		    */
    "UP_THORN",					/* 0xDE			    */
    "SHARP_S",					/* 0xDF	(german sz)	    */
    "LO_A_GRAVE_ACCENT",			/* 0xE0	(a`)		    */
    "LO_A_ACUTE_ACCENT",			/* 0xE1	(a')		    */
    "LO_A_CIRCUMFLEX",				/* 0xE2	(a^)		    */
    "LO_A_TILDE_ACCENT",			/* 0xE3	(a~)		    */
    "LO_A_UMLAUT",				/* 0xE4	(a")		    */
    "LO_A_DEGREE",				/* 0xE5	(a ring)	    */
    "LO_AE_LIGATURE",				/* 0xE6 (ae)		    */
    "LO_C_CEDILLA",				/* 0xE7 (cd)		    */
    "LO_E_GRAVE_ACCENT",			/* 0xE8 (e`)		    */
    "LO_E_ACUTE_ACCENT",			/* 0xE9	(e')		    */
    "LO_E_CIRCUMFLEX",				/* 0xEA	(e^)		    */
    "LO_E_UMLAUT",				/* 0xEB	(e")		    */
    "LO_I_GRAVE_ACCENT",			/* 0xEC (i`)		    */
    "LO_I_ACUTE_ACCENT",			/* 0xED	(i')		    */
    "LO_I_CIRCUMFLEX",				/* 0xEE	(i^)		    */
    "LO_I_UMLAUT",				/* 0xEF	(i")		    */
    "LO_D_WITH_STROKE",				/* 0xF0	(d-)		    */
    "LO_N_TILDE_ACCENT",			/* 0xF1	(n~)		    */
    "LO_O_GRAVE_ACCENT",			/* 0xF2	(o`)		    */
    "LO_O_ACUTE_ACCENT",			/* 0xF3	(o')		    */
    "LO_O_CIRCUMFLEX",				/* 0xF4	(o^)		    */
    "LO_O_TILDE_ACCENT",			/* 0xF5	(o~)		    */
    "LO_O_UMLAUT",				/* 0xF6	(o")		    */
    "MATH_DIVISION",				/* 0xF7 (:-)		    */
    "LO_O_CROSSBAR",				/* 0xF8	(o/)		    */
    "LO_U_GRAVE_ACCENT",			/* 0xF9	(u`)		    */
    "LO_U_ACUTE_ACCENT",			/* 0xFA	(u')		    */
    "LO_U_CIRCUMFLEX",				/* 0xFB	(u^)		    */
    "LO_U_UMLAUT",				/* 0xFC	(u")		    */
    "LO_Y_ACUTE_ACCENT",			/* 0xFD	(y')		    */
    "LO_THORN",					/* 0xFE			    */
    "LO_Y_UMLAUT",				/* 0xFF	(y")		    */

/*----------------------------------------------------------------------------
 *  First 64 of 256 Function keys (0x100 - 0x13F):
 *--------------------------------------------------------------------------*/

    "KEY_DOWN",			/* 0x100 Down arrow key			    */
    "KEY_UP",			/* 0x101 Up arrow key			    */
    "KEY_LEFT",			/* 0x102 Left arrow key			    */
    "KEY_RIGHT",		/* 0x103 Right arrow key		    */
    "KEY_SDOWN",		/* 0x104 Shifted down arrow key		    */
    "KEY_SUP",			/* 0x105 Shifted up arrow key		    */
    "KEY_SLEFT",		/* 0x106 Shifted left arrow key		    */
    "KEY_SRIGHT",		/* 0x107 Shifted left arrow key		    */
    "KEY_HOME",			/* 0x108 Home key			    */
    "KEY_SHOME",		/* 0x109 Shifted home key		    */
    "KEY_DL",			/* 0x10A Delete line key		    */
    "KEY_IL",			/* 0x10B Insert line key		    */
    "KEY_DW",			/* 0x10C Delete word key		    */
    "KEY_IW",			/* 0x10D Insert word key		    */
    "KEY_DC",			/* 0x10E Delete character key		    */
    "KEY_IC",			/* 0x10F Ins char/toggle ins mode key	    */
    "KEY_CLEAR",		/* 0x110 Clear screen or erase key	    */
    "KEY_SCLEAR",		/* 0x111 Shifted clear screen/erase key	    */
    "KEY_EOS",			/* 0x112 Clear-to-end-of-screen key	    */
    "KEY_EOL",			/* 0x113 Clear-to-end-of-line key	    */
    "KEY_NPAGE",		/* 0x114 Next-page key			    */
    "KEY_PPAGE",		/* 0x115 Previous-page key		    */
    "KEY_PRINT",		/* 0x116 Print or copy			    */
    "KEY_BTAB",			/* 0x117 Back tab key			    */
    "KEY_END",			/* 0x118 End key			    */
    "KEY_FIND",			/* 0x119 Find key (vt200)		    */
    "KEY_SELECT",		/* 0x11A Select key (vt200)		    */
    "KEY_MODE",			/* 0x11B Mode key (97801)		    */
    "KEY_SMODE",		/* 0x11C Shifted Mode key (97801)	    */
    "KEY_HELP",			/* 0x11D Help key (97801)		    */
    "KEY_START",		/* 0x11E Start key (97801)		    */
    "KEY_0x11F",		/* 0x11F UNUSED !			    */
    "KEY_PAD_0",		/* 0x120 VT100 keypad 0 key		    */
    "KEY_PAD_1",		/* 0x121 VT100 keypad 1 key		    */
    "KEY_PAD_2",		/* 0x122 VT100 keypad 2 key		    */
    "KEY_PAD_3",		/* 0x123 VT100 keypad 3 key		    */
    "KEY_PAD_4",		/* 0x124 VT100 keypad 4 key		    */
    "KEY_PAD_5",		/* 0x125 VT100 keypad 5 key		    */
    "KEY_PAD_6",		/* 0x126 VT100 keypad 6 key		    */
    "KEY_PAD_7",		/* 0x127 VT100 keypad 7 key		    */
    "KEY_PAD_8",		/* 0x128 VT100 keypad 8 key		    */
    "KEY_PAD_9",		/* 0x129 VT100 keypad 9 key		    */
    "KEY_PAD_MINUS",		/* 0x12A VT100 keypad - (minus) key	    */
    "KEY_PAD_COMMA",		/* 0x12B VT100 keypad , (comma) key	    */
    "KEY_PAD_PERIOD",		/* 0x12C VT100 keypad . (period) key	    */
    "KEY_PAD_ENTER",		/* 0x12D VT100 keypad ENTER key		    */
    "KEY_0x12E",		/* 0x12E UNUSED !			    */
    "KEY_0x12F",		/* 0x12F UNUSED !			    */
    "KEY_PAD_PF0",		/* 0x130 Siemens pseudo PF0		    */
    "KEY_PAD_PF1",		/* 0x131 VT100 or Siemens pseudo PF1 key    */
    "KEY_PAD_PF2",		/* 0x132 VT100 or Siemens pseudo PF2 key    */
    "KEY_PAD_PF3",		/* 0x133 VT100 or Siemens pseudo PF3 key    */
    "KEY_PAD_PF4",		/* 0x134 VT100 or Siemens pseudo PF4 key    */
    "KEY_SPAD_PF0",		/* 0x135 Shifted PF0 key (which has it?)    */
    "KEY_SPAD_PF1",		/* 0x136 Shifted PF1 key (Facit Twist)      */
    "KEY_SPAD_PF2",		/* 0x137 Shifted PF2 key (Facit Twist)      */
    "KEY_SPAD_PF3",		/* 0x138 Shifted PF3 key (Facit Twist)      */
    "KEY_SPAD_PF4",		/* 0x139 Shifted PF4 key (Facit Twist)      */
    "KEY_WORD_LEFT",		/* 0x13A Word-Left key (97801)		    */
    "KEY_WORD_RIGHT",		/* 0x13B Word-Right key (97801)		    */
    "KEY_0x13C",		/* 0x13C UNUSED !			    */
    "KEY_L_BUTTON",		/* 0x13D X-Driver: left mouse button	    */
    "KEY_M_BUTTON",		/* 0x13E X-Driver: middle mouse button	    */
    "KEY_R_BUTTON",		/* 0x13F X-Driver: right mouse button	    */

    (char *) NULL		/* terminator				    */
};

/* End of map-table.h */
